using System.Reflection;
using AutobusApi.Domain.Entities;
using Microsoft.EntityFrameworkCore;

namespace AutoubsApi.Persistence.Contexts;

public class PostgresContext : DbContext
{
    public PostgresContext(DbContextOptions<PostgresContext> options)
        : base(options) { }

    public DbSet<Country> Countries { get; set; }

    public DbSet<Region> Regions { get; set; }

    public DbSet<City> Cities { get; set; }

    public DbSet<Address> Addresses { get; set; }

    public DbSet<RouteAddress> RouteAddresses { get; set; }

    public DbSet<Route> Routes { get; set; }

    public DbSet<RouteAddressDetails> RouteAddressDetails { get; set; }

    public DbSet<VehicleEnrollment> VehicleEnrollments { get; set; }

    public DbSet<Vehicle> Vehicles { get; set; }

    public DbSet<Bus> Buses { get; set; }

    public DbSet<Aircraft> Aircraft { get; set; }

    public DbSet<Train> Trains { get; set; }

    public DbSet<TrainCarriage> TrainCarriages { get; set; }

    public DbSet<Carriage> Carriages { get; set; }

    public DbSet<Company> Companies { get; set; }

    public DbSet<Employee> Employees { get; set; }

    public DbSet<EmployeeDocument> EmployeeDocuments { get; set; }

    public DbSet<VehicleEnrollmentEmployee> vehicleEnrollmentEmployees { get; set; }

    public DbSet<User> Users { get; set; }

    public DbSet<TicketGroup> TicketGroups { get; set; }

    public DbSet<Ticket> Tickets { get; set; }

    public DbSet<TicketDocument> TicketDocuments { get; set; }

    public DbSet<Review> Reviews { get; set; }

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.HasPostgresExtension("postgis");

        modelBuilder.ApplyConfigurationsFromAssembly(Assembly.GetExecutingAssembly());
    }
}
